/*
  Copyright (C) 2013 Alessandro Bugatti (alessandro.bugatti@istruzione.it)

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

/*! \file
 *  \brief Realizzazione del grafico del modulo della risposta in frequenza di un
 *  filtro passa basso passivo
 *  La formula vale
 *  modulo(f) = 1/sqrt(1+(2*pi_greco*f*R*C)^2)
 *  \author Alessandro Bugatti
 *  \version 0.1
 *  \date  Creazione 04/02/2013
 *  \date  Ultima modifica 04/02/2013
 */
#include <math.h>

#include "vsgl_types.h"
#include "vsgl.h"

int const NUMERO_CAMPIONI = 800;
int const ALTEZZA = 600;

float modulo[NUMERO_CAMPIONI];

void calcola_risposta(float m[], int n, float frequenza_massima, float R, float C)
{
    int i;
    float frequenza;
    for (i = 0; i < n; i++)
    {
        frequenza = i*frequenza_massima/n;
        modulo[i] = 1/sqrt(1+(2*M_PI*frequenza*R*C)*(2*M_PI*frequenza*R*C));
    }
}

void disegna_grafico(float m[], int n, int altezza, float frequenza_massima)
{
    int i;
    int x1,y1;
    for (i = 0; i < n-1; i++)
    {
        x1 = i;
        y1 = altezza*(1-m[i]);
        disegna_punto(x1,y1,GIALLO);
    }
}

int main(int argc, char *argv[])
{
    char valore[100];
    float R,C,F_max;
    inizializza_grafica(ALTEZZA,NUMERO_CAMPIONI,0,"Filtro passa basso");
    leggi_stringa(valore,"Inserisci il valore di R (Ohm): ",1,0,0,BIANCO);
    R = atof(valore);
    leggi_stringa(valore,"Inserisci il valore di C (Farad): ",1,0,0,BIANCO);
    C = atof(valore);
    leggi_stringa(valore,"Inserisci il valore di frequenza massima (Hz): ",1,0,0,BIANCO);
    F_max = atof(valore);
    calcola_risposta(modulo,NUMERO_CAMPIONI, F_max,R,C);
    disegna_grafico(modulo,NUMERO_CAMPIONI,ALTEZZA,F_max);
    aggiorna_schermo();
    //Attende la pressione di un tasto per continuare. Se non ci fosse
    //il programma si chiuderebbe subito senza dare il tempo di vedere quanto fatto
    pausa();
    return 0;
}

