/*
  Copyright (C) 2011 Alessandro Bugatti (alessandro.bugatti@istruzione.it)

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

#include <vector>
#include "vsgl.h"

using namespace std;

vector <OggettoGrafico*> listaOggetti;
Colore COLORE_SFONDO;
int mouseX, mouseY;
bool mouseTD, mouseTS;
Mix_Music *music; // Musica

void inizializza_grafica(int larghezza, int altezza, int fullscreen, const char* titolo)
{
    screen(larghezza, altezza, fullscreen, titolo);
    cls(NERO);
    redraw();
}

/// TODO (alex#5#): Da mettere a posto, questo è solo un rattoppo veloce
void inizializza_audio()
{
    if(Mix_OpenAudio(44100, AUDIO_S16SYS, 2, 2048) < 0)
        exit(1);
}

void carica_musica(const char *nomefile)
{
    music = Mix_LoadMUS(nomefile);
}

void suona_musica()
{
    Mix_PlayMusic(music, 0);
}

void ferma_musica()
{
    Mix_HaltMusic();
}

void disegna_punto(int x, int y, const Colore& c)
{
    pset(x, y, c);
}

Colore crea_colore(int r, int g, int b)
{
    return ColorRGB(r,g,b);
}

void scrivi( int x, int y, const char *s, const Colore& c)
{
    print(s, x, y, c);
}

void aggiorna_schermo()
{
    redraw();
}

void pausa()
{
    sleep();
}

void pulisci_schermo(const Colore& c)
{
    if (c == NESSUN_COLORE)
        cls(COLORE_SFONDO);
    else
        cls(c);
}

void imposta_colore_sfondo(const Colore& c)
{
    COLORE_SFONDO = c;
}

int crea_rettangolo(int x, int y, int larghezza, int altezza, const Colore& c)
{
    OggettoGrafico *temp = new Rettangolo(x,y,larghezza,altezza,c);
    listaOggetti.push_back(temp);
    return listaOggetti.size() - 1;
}

int crea_cerchio(int x, int y, int r, const Colore& c)
{
    OggettoGrafico *temp = new Cerchio(x,y,r,c);
    listaOggetti.push_back(temp);
    return listaOggetti.size() - 1;
}

int crea_disco(int x, int y, int r, const Colore& c)
{
    OggettoGrafico *temp = new Disco(x,y,r,c);
    listaOggetti.push_back(temp);
    return listaOggetti.size() - 1;
}


int crea_linea(int x1, int y1, int x2, int y2, const Colore& c)
{
    OggettoGrafico *temp = new Linea(x1,y1,x2,y2,c);
    listaOggetti.push_back(temp);
    return listaOggetti.size() - 1;
}

int crea_sprite(int x, int y, const string& filename)
{
    OggettoGrafico *temp = new Sprite(x,y,filename);
    listaOggetti.push_back(temp);
    return listaOggetti.size() - 1;
}


void disegna_oggetto(int indice_oggetto)
{
    if (indice_oggetto >= 0 && indice_oggetto < listaOggetti.size())
        listaOggetti.at(indice_oggetto)->disegna();
}

void disegna_oggetti()
{
    vector<OggettoGrafico*>::iterator i;
    for ( i = listaOggetti.begin(); i != listaOggetti.end(); ++i)
        (*i)->disegna();
}

void muovi_oggetto(int x, int y, int indice_oggetto)
{
    if (indice_oggetto >= 0 && indice_oggetto < listaOggetti.size())
        listaOggetti.at(indice_oggetto)->muovi(x,y);
}

void ritardo(int millisecondi)
{
    SDL_Delay(millisecondi);
}

void leggi_mouse()
{
    getMouseState(mouseX,mouseY,mouseTD,mouseTS);
}

int fatto()
{
    return done();
}

void leggi_stringa(char* input, const char* messaggio, int cancella, int x, int y, const Colore& c)
{
    string text, message;
    message = messaggio;
    getInputString(text, message, cancella, x, y, c);
    strcpy(input, text.c_str());
}

void leggi_tastiera()
{
    readKeys();
}

bool tasto_premuto(int tasto)
{
    return keyPressed(tasto);
}

void versione(char *s)
{
    strcpy(s,FULLVERSION_STRING);
}

unsigned long millisecondi()
{
    return getTicks();
}

int cacca()
{

}
